@@ -9,7 +9,7 @@
 #
 package Config::Model::Tester;
 # ABSTRACT: Test framework for Config::Model
-$Config::Model::Tester::VERSION = '2.051';
+$Config::Model::Tester::VERSION = '2.052';
 use warnings;
 use strict;
 use locale;
@@ -136,7 +136,7 @@ sub write_config_file {
 sub check_load_warnings {
     my ($root,$t) = @_ ;
 
-    if ( exists $t->{load_warnings} and not defined $t->{load_warnings} ) {
+    if ( ($t->{no_warnings} or exists $t->{load_warnings}) and not defined $t->{load_warnings}) {
         local $Config::Model::Value::nowarning = 1;
         $root->init;
         ok( 1,"Read configuration and created instance with init() method without warning check" );
@@ -153,8 +153,10 @@ sub run_update {
 
     my $ret = delete $args{returns};
 
-    note("updating config with %args");
-    my $res = $inst->update( from_dir => $dir, quiet => 1, %args ) ;
+    local $Config::Model::Value::nowarning = $args{no_warnings} || $t->{no_warnings} || 0;
+
+    note("updating config with ". join(' ',%args));
+    my $res = $inst->update( from_dir => $dir, %args ) ;
     if (defined $ret) {
         is($res,$ret,"updated configuration, got expected return value");
     }
@@ -199,7 +201,7 @@ sub dump_tree_full_mode {
         }
     }
 
-    if ( exists $t->{dump_warnings} and not defined $t->{dump_warnings} ) {
+    if ( ($t->{no_warnings} or (exists $t->{dump_warnings}) and not defined $t->{dump_warnings}) ) {
         local $Config::Model::Value::nowarning = 1;
         &$risky;
         ok( 1, "Ran dump_tree (no warning check)" );
@@ -213,6 +215,8 @@ sub dump_tree_full_mode {
     return $dump;
 }
 
+# TODO: factorise with function above and create parameters to
+# handle warnings in both cases with warnings_like
 sub dump_tree_custom_mode {
     my ($label, $root, $t, $trace) = @_;
 
@@ -412,7 +416,7 @@ sub run_model_test {
     my $idx = 0;
     foreach my $t (@tests) {
         my $t_name = $t->{name} || "t$idx";
-        if ( defined $do and $do ne $t_name ) {
+        if ( defined $do and $t_name !~ /$do/) {
             $idx++;
             next;
         }
@@ -462,9 +466,11 @@ sub run_model_test {
 
         my $p2_dump = dump_tree_custom_mode("second $model_test", $i2_root, $t) ;
 
+        unified_diff;
         eq_or_diff(
-            $p2_dump, $dump,
-            "compare original $model_test custom data with 2nd instance custom data"
+            [ split /\n/,$p2_dump ],
+            [ split /\n/,$dump ],
+            "compare original $model_test custom data with 2nd instance custom data",
         );
 
         ok( -s "$wr_dir2/$conf_dir/$conf_file_name" ,
@@ -539,7 +545,7 @@ Config::Model::Tester - Test framework for Config::Model
 
 =head1 VERSION
 
-version 2.051
+version 2.052
 
 =head1 SYNOPSIS
 
@@ -677,6 +683,12 @@ Here, C<t0> file will be copied in C<wr_root/test-t0/etc/fstab>.
 
  1; # to keep Perl happy
 
+You can suppress warnings by specifying C<< no_warnings => 1 >>. On
+the other hand, you may also want to check for warnings specifid to
+your model. In this case, you should avoid specifying C<no_warnings>
+here and use the more specify warning tests or warning filters
+mentioned below.
+
 See actual L<fstab test|https://github.com/dod38fr/config-model/blob/master/t/model_tests.d/fstab-test-conf.pl>.
 
 =head2 Internal tests
@@ -744,10 +756,11 @@ Use an empty array_ref to masks load warnings.
 
 Optionally run L<update|App::Cme::Command::update> command:
 
-    update => { in => 'some-test-data.txt', returns => 'foo' }
+    update => { in => 'some-test-data.txt', returns => 'foo' , no_warnings => [ 0 | 1 ] }
 
-C<returns> is the expected return value (optional). All other arguments are passed to C<update>
-method.
+C<returns> is the expected return value (optional). All other
+arguments are passed to C<update> method. Note that C<< quiet => 1 >>
+may be useful for less verbose test.
 
 =item *
 
@@ -846,7 +859,7 @@ Write back the config data in C<< wr_root/<subtest name>/ >>.
 Note that write back is forced, so the tested configuration files are
 written back even if the configuration values were not changed during the test.
 
-You can skip warning when writing back with:
+You can skip warning when writing back with the global :
 
     no_warnings => 1,
 
@@ -945,10 +958,13 @@ The model name to tests. E.g.:
 
 =item *
 
-The required subtest E.g.:
+A regexp to filter subtest E.g.:
 
-  # run only fstab tests t0
-  prove -lv t/model_test.t :: x fstab t0
+  # run only fstab tests foobar subtest
+  prove -lv t/model_test.t :: x fstab foobar
+
+  # run only fstab tests foo subtest
+  prove -lv t/model_test.t :: x fstab '^foo$'
 
 =back
 
